@@ -1,4 +1,4 @@
-/* Copyright © 2007-2017 Jakub Wilk <jwilk@jwilk.net>
+/* Copyright © 2007-2018 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
  * This file is part of pdf2djvu.
@@ -114,7 +114,7 @@ static void parse_pages(const std::string &s, std::vector< std::pair<int, int> >
   {
     if ('0' <= c && c <= '9')
     {
-      value[state] = value[state] * 10 + (int)(c - '0');
+      value[state] = value[state] * 10 + static_cast<int>(c - '0');
       if (state == 0)
         value[1] = value[0];
     }
@@ -318,11 +318,10 @@ void Config::read_config(int argc, char * const argv[])
     { "words", 0, nullptr, OPT_TEXT_WORDS },
     { nullptr, 0, nullptr, '\0' }
   };
-  int optindex, c;
+  int c;
   while (true)
   {
-    optindex = 0;
-    c = getopt_long(argc, argv, "i:o:d:qvp:j:h", options, &optindex);
+    c = getopt_long(argc, argv, "i:o:d:qvp:j:h", options, nullptr);
     if (c < 0)
       break;
     if (c == 0)
@@ -517,14 +516,10 @@ void Config::read_config(int argc, char * const argv[])
     }
 }
 
-void Config::usage(const Config::Error &error) const
+template <typename streamtp>
+static void print_usage(streamtp &stream)
 {
-  DebugStream &log = debug(0, this->verbose);
-  if (error.is_already_printed())
-    log << std::endl;
-  if (!error.is_quiet())
-    log << error << std::endl << std::endl;
-  log
+  stream
     << _("Usage: ") << std::endl
     << _("   pdf2djvu [-o <output-djvu-file>] [options] <pdf-file>") << std::endl
     << _("   pdf2djvu  -i <index-djvu-file>   [options] <pdf-file>") << std::endl
@@ -575,4 +570,19 @@ void Config::usage(const Config::Error &error) const
     << std::endl;
 }
 
+void Config::usage(const Config::Error &error) const
+{
+  DebugStream &log = debug(0, this->verbose);
+  if (error.is_already_printed())
+    log << std::endl;
+  if (!error.is_quiet())
+    log << error << std::endl << std::endl;
+  print_usage(log);
+}
+
+void Config::usage() const
+{
+  print_usage(std::cout);
+}
+
 // vim:ts=2 sts=2 sw=2 et
