@@ -32,7 +32,7 @@
 #include <GlobalParams.h>
 #include <PDFDoc.h>
 #include <goo/GooString.h>
-#include <goo/gtypes.h>
+#include <goo/gfile.h>
 #include <splash/SplashClip.h>
 #include <splash/SplashTypes.h>
 
@@ -226,7 +226,7 @@ const std::string pdf::Document::get_xmp()
   mstring.reset(this->readMetadata());
   if (mstring.get() == nullptr)
     return "";
-  const char *cstring = mstring->getCString();
+  const char *cstring = pdf::get_c_string(mstring.get());
   if (strncmp(cstring, "<?xpacket begin=", 16) != 0)
     return "";
   cstring += 16;
@@ -393,7 +393,7 @@ pdf::Metadata::Metadata(pdf::Document &document)
     char tzs = 0; int tzh = 0, tzm = 0;
     if (!pdf::dict_lookup(info_dict, field.first, &object)->isString())
       continue;
-    const char *input = object.getString()->getCString();
+    const char *input = pdf::get_c_string(object.getString());
     if (input[0] == 'D' && input[1] == ':')
       input += 2;
     int year = scan_date_digits(input, 4);
@@ -619,4 +619,16 @@ namespace pdf
   }
 }
 
+#if POPPLER_VERSION >= 7200
+const char * pdf::get_c_string(const pdf::String *str)
+{
+  return str->c_str();
+}
+#else
+const char * pdf::get_c_string(const pdf::String *str)
+{
+  return str->getCString();
+}
+#endif
+
 // vim:ts=2 sts=2 sw=2 et
