@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2015-2017 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of pdf2djvu.
 #
@@ -13,15 +13,16 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # General Public License for more details.
 
+import re
+
 from tools import (
     assert_equal,
     case,
-    re,
 )
 
 class test(case):
-    # Bug: https://bitbucket.org/jwilk/pdf2djvu/issue/98
-    # + fixed in 0.8 [e98f3c4cfa2e]
+    # Bug: https://github.com/jwilk/pdf2djvu/issues/98
+    # + fixed in 0.8 [ec2d2e6f7101f7693dac8d102c0dce1fa879f346]
 
     def test_overwrite(self):
         pdf_path = self.get_pdf_path()
@@ -33,7 +34,7 @@ class test(case):
             '-o', self.get_pdf_path()
         ))
         r = self.run(*cmdline)
-        r.assert_(stderr=re('Input file is the same as output file:'), rc=1)
+        r.assert_(stderr=re.compile('Input file is the same as output file:'), rc=1)
         with open(pdf_path, 'rb') as pdf_file:
             pdf_after = pdf_file.read()
         assert_equal(pdf_before, pdf_after)
